@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/osrs/libtiff/tools/ras2tiff.c,v 1.7 2003/11/12 19:14:33 dron Exp $ */
+/* $Id: ras2tiff.c,v 1.22 2015-06-21 01:09:10 bfriesen Exp $ */
 
 /*
  * Copyright (c) 1988-1997 Sam Leffler
@@ -24,10 +24,21 @@
  * OF THIS SOFTWARE.
  */
 
+#include "tif_config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#include <limits.h>
+
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
+#ifdef NEED_LIBPORT
+# include "libport.h"
+#endif
 
 #include "rasterfile.h"
 #include "tiffio.h"
@@ -38,10 +49,6 @@
 #define	streq(a,b)	(strcmp(a,b) == 0)
 #define	strneq(a,b,n)	(strncmp(a,b,n) == 0)
 
-#ifndef BINMODE
-#define	BINMODE
-#endif
-
 static	uint16 compression = (uint16) -1;
 static	int jpegcolormode = JPEGCOLORMODE_RGB;
 static	int quality = 75;		/* JPEG quality */
@@ -54,7 +61,7 @@ int
 main(int argc, char* argv[])
 {
 	unsigned char* buf;
-	uint32 row;
+	long row;
 	tsize_t linebytes, scanline;
 	TIFF *out;
 	FILE *in;
@@ -63,8 +70,10 @@ main(int argc, char* argv[])
 	uint16 config = PLANARCONFIG_CONTIG;
 	uint32 rowsperstrip = (uint32) -1;
 	int c;
+#if !HAVE_DECL_OPTARG
 	extern int optind;
 	extern char* optarg;
+#endif
 
 	while ((c = getopt(argc, argv, "c:r:h")) != -1)
 		switch (c) {
@@ -81,42 +90,66 @@ main(int argc, char* argv[])
 		}
 	if (argc - optind != 2)
 		usage();
-	in = fopen(argv[optind], "r" BINMODE);
+	in = fopen(argv[optind], "rb");
 	if (in == NULL) {
 		fprintf(stderr, "%s: Can not open.\n", argv[optind]);
 		return (-1);
 	}
 	if (fread(&h, sizeof (h), 1, in) != 1) {
 		fprintf(stderr, "%s: Can not read header.\n", argv[optind]);
+		fclose(in);
 		return (-2);
 	}
 	if (strcmp(h.ras_magic, RAS_MAGIC) == 0) {
-#if (HOST_BIGENDIAN == 0)
-			TIFFSwabLong(&h.ras_width);
-			TIFFSwabLong(&h.ras_height);
-			TIFFSwabLong(&h.ras_depth);
-			TIFFSwabLong(&h.ras_length);
-			TIFFSwabLong(&h.ras_type);
-			TIFFSwabLong(&h.ras_maptype);
-			TIFFSwabLong(&h.ras_maplength);
+#ifndef WORDS_BIGENDIAN
+			TIFFSwabLong((uint32 *)&h.ras_width);
+			TIFFSwabLong((uint32 *)&h.ras_height);
+			TIFFSwabLong((uint32 *)&h.ras_depth);
+			TIFFSwabLong((uint32 *)&h.ras_length);
+			TIFFSwabLong((uint32 *)&h.ras_type);
+			TIFFSwabLong((uint32 *)&h.ras_maptype);
+			TIFFSwabLong((uint32 *)&h.ras_maplength);
 #endif
 	} else if (strcmp(h.ras_magic, RAS_MAGIC_INV) == 0) {
-#if (HOST_BIGENDIAN == 1)
-			TIFFSwabLong(&h.ras_width);
-			TIFFSwabLong(&h.ras_height);
-			TIFFSwabLong(&h.ras_depth);
-			TIFFSwabLong(&h.ras_length);
-			TIFFSwabLong(&h.ras_type);
-			TIFFSwabLong(&h.ras_maptype);
-			TIFFSwabLong(&h.ras_maplength);
+#ifdef WORDS_BIGENDIAN
+			TIFFSwabLong((uint32 *)&h.ras_width);
+			TIFFSwabLong((uint32 *)&h.ras_height);
+			TIFFSwabLong((uint32 *)&h.ras_depth);
+			TIFFSwabLong((uint32 *)&h.ras_length);
+			TIFFSwabLong((uint32 *)&h.ras_type);
+			TIFFSwabLong((uint32 *)&h.ras_maptype);
+			TIFFSwabLong((uint32 *)&h.ras_maplength);
 #endif
 	} else {
 		fprintf(stderr, "%s: Not a rasterfile.\n", argv[optind]);
+		fclose(in);
 		return (-3);
 	}
+        if ((h.ras_width <= 0) || (h.ras_width >= INT_MAX) ||
+            (h.ras_height <= 0) || (h.ras_height >= INT_MAX) ||
+            (h.ras_depth <= 0) || (h.ras_depth >= INT_MAX) ||
+            (h.ras_length <= 0) || (h.ras_length >= INT_MAX) ||
+            (h.ras_type <= 0) ||
+            (h.ras_maptype <= 0) ||
+            (h.ras_maplength <= 0) || (h.ras_maplength >= INT_MAX)) {
+                fprintf(stderr, "%s: Improper image header.\n", argv[optind]);
+                fclose(in);
+		return (-2);
+        }
+        if ((h.ras_depth != 1) &&
+            (h.ras_depth != 8) &&
+            (h.ras_depth != 24)) {
+                fprintf(stderr, "%s: Improper image depth (%d).\n",
+                        argv[optind], h.ras_depth);
+                fclose(in);
+		return (-2);
+        }
 	out = TIFFOpen(argv[optind+1], "w");
 	if (out == NULL)
+	{
+		fclose(in);
 		return (-4);
+	}
 	TIFFSetField(out, TIFFTAG_IMAGEWIDTH, (uint32) h.ras_width);
 	TIFFSetField(out, TIFFTAG_IMAGELENGTH, (uint32) h.ras_height);
 	TIFFSetField(out, TIFFTAG_ORIENTATION, ORIENTATION_TOPLEFT);
@@ -201,8 +234,8 @@ main(int argc, char* argv[])
 	    TIFFDefaultStripSize(out, rowsperstrip));
 	for (row = 0; row < h.ras_height; row++) {
 		if (fread(buf, linebytes, 1, in) != 1) {
-			fprintf(stderr, "%s: scanline %lu: Read error.\n",
-			    argv[optind], (unsigned long) row);
+			fprintf(stderr, "%s: scanline %ld: Read error.\n",
+			    argv[optind], row);
 			break;
 		}
 		if (h.ras_type == RT_STANDARD && h.ras_depth == 24) {
@@ -218,6 +251,7 @@ main(int argc, char* argv[])
 			break;
 	}
 	(void) TIFFClose(out);
+	fclose(in);
 	return (0);
 }
 
@@ -230,11 +264,19 @@ processCompressOptions(char* opt)
 		compression = COMPRESSION_PACKBITS;
 	else if (strneq(opt, "jpeg", 4)) {
 		char* cp = strchr(opt, ':');
-		if (cp && isdigit(cp[1]))
+
+                compression = COMPRESSION_JPEG;
+                while( cp )
+                {
+                    if (isdigit((int)cp[1]))
 			quality = atoi(cp+1);
-		if (cp && strchr(cp, 'r'))
+                    else if (cp[1] == 'r' )
 			jpegcolormode = JPEGCOLORMODE_RAW;
-		compression = COMPRESSION_JPEG;
+                    else
+                        usage();
+
+                    cp = strchr(cp+1,':');
+                }
 	} else if (strneq(opt, "lzw", 3)) {
 		char* cp = strchr(opt, ':');
 		if (cp)
@@ -256,7 +298,6 @@ char* stuff[] = {
 " -r #		make each strip have no more than # rows",
 "",
 " -c lzw[:opts]	compress output with Lempel-Ziv & Welch encoding",
-"               (no longer supported by default due to Unisys patent enforcement)", 
 " -c zip[:opts]	compress output with deflate encoding",
 " -c jpeg[:opts]	compress output with JPEG encoding",
 " -c packbits	compress output with packbits encoding",
@@ -286,3 +327,12 @@ usage(void)
 		fprintf(stderr, "%s\n", stuff[i]);
 	exit(-1);
 }
+
+/* vim: set ts=8 sts=8 sw=8 noet: */
+/*
+ * Local Variables:
+ * mode: c
+ * c-basic-offset: 8
+ * fill-column: 78
+ * End:
+ */
